﻿using System.Linq;
using System.Collections.Generic;
using System.Web.Mvc;
using MvcApplication1.Models;
using Tracker.Data.Entities;
using Tracker.Data.Infrastructure;

namespace MvcApplication1.Controllers
{
    public class HomeController : Controller
    {
		private readonly IIntKeyedRepository<Truck> _truckRepository;
        private readonly IUnitOfWork _unitOfWork;

        public HomeController(IIntKeyedRepository<Truck> truckRepository, IUnitOfWork unitOfWork)
		{
			_truckRepository = truckRepository;

		    _unitOfWork = unitOfWork;
		}

        public ActionResult Index()
        {
            return View(_truckRepository.All().OrderBy(x=>x.Name));
        }

		public ActionResult Position(int truckId)
		{
            if (Request.IsAjaxRequest())
            {
                JsonMapper mapper = new JsonMapper(_truckRepository);
                JsonTruckInfo jsonTruckInfo = mapper.MapToTruckInfo(truckId);
                if (jsonTruckInfo != null)
                {
                    return Json(jsonTruckInfo, JsonRequestBehavior.AllowGet);
                }
            }
		    return new EmptyResult();
		}

		public ActionResult History(int truckId, int count)
		{
            if (Request.IsAjaxRequest())
            {
                JsonMapper mapper = new JsonMapper(_truckRepository);
                List<JsonLocation> locations = mapper.MapToLocations(truckId, count);
                if (locations != null)
                {
                    return Json(locations, JsonRequestBehavior.AllowGet);
                }
            }
		    return new EmptyResult();
		}

        public ActionResult Add()
        {
            return View();
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult Add(NewTruckInfo newTruckInfo)
        {
            newTruckInfo.AddTruckWithFakeGpsData(_truckRepository, _unitOfWork);
            return RedirectToAction("Index");
        }
    }
}
