﻿using System.Collections.Generic;
using System.Linq;
using Tracker.Data.Entities;
using Tracker.Data.Infrastructure;

namespace MvcApplication1.Models
{
    public class JsonMapper
    {
        private readonly IIntKeyedRepository<Truck> _truckRepository;

        public JsonMapper(IIntKeyedRepository<Truck> truckRepository)
        {
            _truckRepository = truckRepository;
        }

        public JsonTruckInfo MapToTruckInfo(int truckId)
        {
            Truck truck = _truckRepository.FindBy(truckId);
            if (truck != null)
            {
                Location location = truck.Locations.OrderByDescending(c => c.Timestamp).First();
                JsonTruckInfo jsonTruckInfo = new JsonTruckInfo
                {
                    driver = truck.Driver.FirstName + " " + truck.Driver.LastName,
                    lat = location.Latitude,
                    lng = location.Longitude,
                    name = truck.Name,
                    plate = truck.PlateNumber,
                    type = truck.Type
                };
                return jsonTruckInfo;
            }
            return null;
        }

        public List<JsonLocation> MapToLocations(int truckId, int count)
        {
            Truck truck = _truckRepository.FindBy(truckId);
            if (truck != null)
            {
                List<JsonLocation> locations =
                    truck.Locations.OrderByDescending(c => c.Timestamp).Take(count).Select(
                        location => new JsonLocation { lat = location.Latitude, lng = location.Longitude }).ToList();

                return locations;
            }
            return null;
        }
    }
}