﻿using System;
using Tracker.Data.Entities;
using Tracker.Data.Infrastructure;

namespace MvcApplication1.Models
{
    public class NewTruckInfo
    {
        public string TruckName { get; set; }
        public string TruckType { get; set; }
        public string TruckPlate { get; set; }
        public string FirstName { get; set; }
        public string LastName { get; set; }
        public double StartLat { get; set; }
        public double StartLng { get; set; }
        public double StopLat { get; set; }
        public double StopLng { get; set; }

        public void AddTruckWithFakeGpsData(IRepository<Truck> repo, IUnitOfWork unitOfWork)
        {
            // No matter where we start or where we end
            //  this trip only takes 24 hours.
            //
            const float numHours = 24.0f;
            DateTime dtStart = DateTime.Now.AddHours(-numHours);

            // Create the truck, driver, and route
            //
            Truck truck = new Truck
            {
                Name = TruckName,
                PlateNumber = TruckPlate,
                Type = TruckType
            };
            Driver driver = new Driver
            {
                FirstName = FirstName,
                LastName = LastName
            };
            truck.AddDriver(driver);

            // Generate 100 GPS points 'as the crow flies'
            //
            const int numPoints = 100;
            float deltaLat = (float)((StopLat - StartLat) / (numPoints - 1));
            float deltaLng = (float)((StopLng - StartLng) / (numPoints - 1));
            const float deltaHours = numHours / (numPoints - 1);

            for (int j = 0; j < numPoints; j++)
            {
                Location location = new Location
                {
                    Latitude = StartLat + deltaLat * j,
                    Longitude = StartLng + deltaLng * j,
                    Timestamp = dtStart.AddHours(deltaHours * j)
                };
                truck.AddLocation(location);
            }

            // Add it to the database.
            //
            repo.Add(truck);
            unitOfWork.Commit();           
        }
    }
}