﻿using System.Configuration;
using NHibernate;
using Ninject;
using Ninject.Activation;
using Ninject.Modules;
using Tracker.Data.Entities;
using Tracker.Data.Infrastructure;
using Tracker.Data.NHibernate;

namespace MvcApplication1.NinjectFramework
{
	public class RepositoryModule : NinjectModule
	{
		public override void Load()
		{
		    string connectionString = ConfigurationManager.ConnectionStrings["TruckTrackerDb"].ConnectionString;

			NHibernateHelper helper = new NHibernateHelper(connectionString);
			Bind<ISessionFactory>().ToConstant(helper.SessionFactory)
				.InSingletonScope();
			
			Bind<IUnitOfWork>().To<UnitOfWork>()
				.InRequestScope();
			Bind<ISession>().ToProvider(new SessionProvider())
				.InRequestScope();
			Bind<IIntKeyedRepository<Truck>>().To<Repository<Truck>>()
				.InRequestScope();
		}
	}

	public class SessionProvider : Provider<ISession>
	{
		protected override ISession CreateInstance(IContext context)
		{
			UnitOfWork unitOfWork = (UnitOfWork)context.Kernel.Get<IUnitOfWork>();
			return unitOfWork.Session;
		}
	}
}