﻿<%@ Page Language="C#" Inherits="System.Web.Mvc.ViewPage<IQueryable<Tracker.Data.Entities.Truck>>" %>
<%@ Import Namespace="Tracker.Data.Entities" %>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" >
<head runat="server">
    <title>Trucks</title>
    <link type="text/css" href="~/Content/css/Site.css" rel="Stylesheet" />
    
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no" />
    <script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.4.2/jquery.min.js"></script>
    <script type="text/javascript" src="http://maps.google.com/maps/api/js?sensor=true"></script>
    <script type="text/javascript" src="Content/scripts/jquery.gmap3.js"></script>
    <script type="text/javascript">

        var map;
        $(document).ready(function () {
            map = $("#map_canvas").gmap3(
            {
                lat: 43.0566,
                lng: -89.4511,
                zoom: 2
            });
            map.setTypeRoadMap();

            animateTruck1();
            animateTruck2();
        });

        function getHistory(id) {
            var url = '<%= Url.Action("History", "Home") %>';
            $.getJSON(url, { truckId: id, count: 50 }, function (data) {
                map.addPath(data);
            });
        }

        function getLocation(id) {
            var url = '<%= Url.Action("Position", "Home") %>';
            $.getJSON(url, { truckId: id, count: 50 }, function (data) {
                map.setCenter(data.lat, data.lng);
                map.setZoom(6);
                // we have the lat/lng...geocode to get address
                $.fn.gmap3.geoCodeLatLng(data.lat, data.lng, function (address) {
                    var latlng = data.lat + ", " + data.lng;
                    map.addMarkerByLatLng(data.lat, data.lng, data.name, createInfo(data.name, data.plate, data.type, data.driver, latlng, address));
                });

            });
        }

        function createInfo(title, plate, type, driver, latlng, location) {
            return '<div class="popup"><h1 class="popup-title">' + title + '</h1><div id="popup-body"><p><span class="popup-label">plate:</span> ' + plate + '</p><p><span class="popup-label">type:</span> ' + type + '</p><p><span class="popup-label">driver:</span> ' + driver + '</p><p><span class="popup-label">lat/lng:</span> ' + latlng + '</p><p><span class="popup-label">location:</span> ' + location + '</p></div></div>';
        }

        function showTruck(id) {
            map.clear();
            getLocation(id);
            getHistory(id);
            $(".selected").removeClass("selected");
            $("#truck-" + id).addClass("selected");
        }

        function animateTruck1() {
            $("#truck1").animate({ 'left': '-100px' }, 50000, 'linear', function () {
                $(this).css('left', '3000px');
                animateTruck1();
            });
        }

        function animateTruck2() {
            $("#truck2").animate({ 'left': '3000px' }, 55000, 'linear', function () {
                $(this).css('left', '-100px');
                animateTruck2();
            });
        }
    </script>
</head>
<body>
 	
    <div class="demo">
		<a href="http://blog.bobcravens.com/" class="demo">Bob <span>Cravens</span> Dotcom Demo Page</a>
	</div>

    <div class="header">
        <span id="truck1" class="truck"></span>
        <span id="truck2" class="truck"></span>
        <h1>Truck Tracker Application</h1>
        <p>This application displays truck locations for a ficticious trucking company. The truck locations are uploaded by the GPS wireless radios. 
        The list on the left displays available trucks. Selecting a truck will show its current location and a trail of the most recent 50 GPS points.</p>
    </div>
    
    <div id="wrapper">

        <div id="truck-list" class="left">
            <h3>Truck List</h3>
            <ul>
                <% foreach(Truck truck in Model) { %>
                <li>
                    <a id="truck-<%= truck.Id %>" href="javascript:showTruck(<%= truck.Id %>)">
                        <span class="truck">
                            <span class="truck-id"><%= truck.Id %></span>
                            <span class="truck-name"><%= truck.Name %></span>
                            <span class="truck-type"><%= truck.Type %></span>
                            <span class="truck-plate"><%= truck.PlateNumber %></span>
                        </span>
                    </a>
                </li>
                <% } %>
            </ul>
        </div>

        <div id="map">
            <div id="map_canvas" class="line"></div>
        </div>

        <div id="footer">
            <div class="left">
                This web site is the user interface for a project intended to be a tutorial to learn a number of technologies.
                In depth information can be found in the blog content listed to the right.
                The following technologies are leveraged:
                <ul>
                    <li><a href="http://www.microsoft.com/net/">.NET Framework</a></li>
                    <li><a href="http://www.mysql.com/">MySQL</a></li>
                    <li><a href="http://nhforge.org/Default.aspx">NHibernate</a></li>
                    <li><a href="http://fluentnhibernate.org/">Fluent NHibernate</a></li>
                    <li><a href="http://sourceforge.net/projects/nhibernate/">LINQ to NHibernate</a></li>
                    <li><a href="http://www.asp.net/mvc">ASP.NET MVC</a></li>
                    <li><a href="http://code.google.com/apis/maps/documentation/javascript/">Google Maps API v.3</a></li>
                    <li><a href="http://jquery.com">jQuery</a></li>
                </ul>
            </div>
            <div class="right">
                <h4>In Depth Tutorials:</h4>
                <ul>
                    <li>
                        <a href="http://blog.bobcravens.com/2010/06/06/AGoogleMapsVersion3JQueryPlugin.aspx">A Google Maps Version 3 jQuery Plugin</a>
                    </li>
                    <li>
                        <a href="http://blog.bobcravens.com/2010/06/01/TheRepositoryPatternWithLinqToFluentNHibernateAndMySQL.aspx">The Repository Pattern with Linq to Fluent NHibernate and MySQL</a>
                    </li>
                    <li>
                        <a href="http://blog.bobcravens.com/2010/07/05/UsingNHibernateInASPNETMVC.aspx">Wiring up NHibernate in ASP.NET MVC using Ninject</a>
                    </li>
                </ul>
            </div>
            <div class="clear">
                <p> 
				    <a rel="license" href="http://creativecommons.org/licenses/by/3.0/us/"> 
					    <img alt="Creative Commons License" style="border-width:0" src="http://creativecommons.org/images/public/somerights20.png" /> 
				    </a>
				</p>
                <p> 
				    This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by/3.0/us/">Creative Commons Attribution 3.0 United States License</a> 
			    </p>
                <p>
                    <%= DateTime.Now.Year %> <a href="http://bobcravens.com">Bob Cravens</a>
                </p>
            </div>
        </div>
    </div>
</body>
</html>
